@@ -208,6 +208,8 @@ tracker_seccomp_init (void)
 	ALLOW_RULE (rt_sigreturn);
 	ALLOW_RULE (sched_yield);
 	ALLOW_RULE (sched_getaffinity);
+	ALLOW_RULE (sched_get_priority_max);
+	ALLOW_RULE (sched_get_priority_min);
 	ALLOW_RULE (sched_setattr);
 	ALLOW_RULE (nanosleep);
 	ALLOW_RULE (clock_nanosleep);
@@ -230,6 +232,8 @@ tracker_seccomp_init (void)
 	ALLOW_RULE (epoll_create1);
 	ALLOW_RULE (epoll_ctl);
 	ALLOW_RULE (epoll_wait);
+	ALLOW_RULE (epoll_pwait);
+	ALLOW_RULE (epoll_pwait2);
 	/* System */
 	ALLOW_RULE (uname);
 	ALLOW_RULE (sysinfo);
