@@ -75,6 +75,9 @@ void     tracker_miner_files_set_mtime_checking   (TrackerMinerFiles *miner,
 
 TrackerStorage * tracker_miner_files_get_storage (TrackerMinerFiles *mf);
 
+gboolean tracker_miner_files_check_allowed_text_file (TrackerMinerFiles *mf,
+                                                      GFile             *file);
+
 G_END_DECLS
 
 #endif /* __TRACKER_MINER_FS_FILES_H__ */
