@@ -180,14 +180,8 @@ signal_handler (gpointer user_data)
 	case SIGINT:
 		in_loop = TRUE;
 		g_main_loop_quit (main_loop);
-
-		/* Fall through */
+		break;
 	default:
-		if (g_strsignal (signo)) {
-			g_message ("Received signal:%d->'%s'",
-			           signo,
-			           g_strsignal (signo));
-		}
 		break;
 	}
 
@@ -492,6 +486,9 @@ miner_pause (const gchar *miner,
 		g_object_unref (main_loop);
 	}
 
+	/* Carriage return, so we paper over the ^C */
+	g_print ("\r");
+
 	g_object_unref (manager);
 
 	return EXIT_SUCCESS;
@@ -731,6 +728,9 @@ daemon_run (void)
 		g_main_loop_unref (main_loop);
 		g_object_unref (notifier);
 
+		/* Carriage return, so we paper over the ^C */
+		g_print ("\r");
+
 		return EXIT_SUCCESS;
 	}
 
@@ -862,6 +862,9 @@ daemon_run (void)
 		g_main_loop_run (main_loop);
 		g_main_loop_unref (main_loop);
 
+		/* Carriage return, so we paper over the ^C */
+		g_print ("\r");
+
 		g_hash_table_unref (miners_progress);
 		g_hash_table_unref (miners_status);
 
@@ -957,9 +960,9 @@ daemon_run (void)
 		gint retval = 0;
 
 		if (kill_miners)
-			retval = tracker_process_stop (TRACKER_PROCESS_TYPE_NONE, TRACKER_PROCESS_TYPE_MINERS);
+			retval = tracker_process_stop (SIGKILL);
 		else if (terminate_miners)
-			retval = tracker_process_stop (TRACKER_PROCESS_TYPE_MINERS, TRACKER_PROCESS_TYPE_NONE);
+			retval = tracker_process_stop (SIGTERM);
 
 		return retval;
 	}
