@@ -63,20 +63,10 @@ def cli_dir():
     return config["TEST_CLI_DIR"]
 
 
-def cli_subcommands_dir():
-    return config["TEST_CLI_SUBCOMMANDS_DIR"]
-
-
 def tap_protocol_enabled():
     return config["TEST_TAP_ENABLED"]
 
 
-def nepomuk_path():
-    parser = configparser.ConfigParser()
-    parser.read(config["TEST_DOMAIN_ONTOLOGY_RULE"])
-    return parser.get("DomainOntology", "OntologyLocation")
-
-
 # This path is used for test data for tests which expect filesystem monitoring
 # to work. For this reason we must avoid it being on a tmpfs filesystem. Note
 # that this MUST NOT be a hidden directory, as Tracker is hardcoded to ignore
